@@ -1,15 +1,14 @@
 from __future__ import division
 
-import collections
 import gc
 import sys
 import timeit
-from itertools import chain
 
 import pytest
 
 from .stats import RunningStats
 
+
 def loadtimer(string):
     if '.' not in string:
         raise ValueError("Value for benchmark-timer must be in dotted form. Eg: 'module.attr'.")
@@ -66,8 +65,9 @@ class Benchmark(RunningStats):
     def done(self):
         return not (self.runs < self._min_runs or self.total < self._max_time) or self.runs >= self._max_runs
 
-    #def __call__(self, function):
-    #    make decorator
+    def __call__(self, function):
+        # TODO: make decorator
+        pass
 
     def __enter__(self):
         self._gcenabled = gc.isenabled()
@@ -82,6 +82,7 @@ class Benchmark(RunningStats):
             gc.enable()
         self.update(end - self._start)
 
+
 class BenchmarkSession(object):
     def __init__(self, config):
         self._options = dict(
@@ -103,9 +104,13 @@ class BenchmarkSession(object):
         return benchmark
 
     def pytest_terminal_summary(self, terminalreporter):
+        if not self._benchmarks:
+            return
         tr = terminalreporter
-
-        tr.write_sep('=', 'benchmarked %s tests' % len(self._benchmarks), yellow=True)
+        tr.write_sep('-',
+                     'benchmark: {0} tests, {1.min_iterations} min interations, {1.max_iterations} max iterations,'
+                     ' {1.max_time} max time'.format(len(self._benchmarks), type('', (), self._options)),
+                     yellow=True)
         worst = {}
         best = {}
         for prop in ('min', 'max', 'avg', 'mean', 'stddev'):
@@ -123,14 +128,14 @@ class BenchmarkSession(object):
         elif overall_min < 1:
             unit, adjustment = 'm', 1000
         else:
-            unit, adjustment = 's', 1
+            unit, adjustment = '', 1
 
         for prop in ('min', 'max', 'avg', 'mean', 'stddev'):
             widths[prop] = min(6, max(
-                len("{:.3f}".format(getattr(benchmark, prop) * adjustment))
+                len("{0:.3f}".format(getattr(benchmark, prop) * adjustment))
                 for benchmark in self._benchmarks
             ))
-        tr.write_line("{:<{}}  {:>{}} {:>{}} {:>{}} {:>{}} {:>{}}".format(
+        tr.write_line("{0:<{1}}  {2:>{3}} {4:>{5}} {6:>{7}} {8:>{9}} {10:>{11}}".format(
             "Name (time in %ss)" % unit, widths['name'],
             'min', widths['min'] + 3,
             'max', widths['max'] + 3,
@@ -141,11 +146,11 @@ class BenchmarkSession(object):
         tr.write_line("-" * sum(widths.values(), 6 + 5 * 3))
 
         for benchmark in self._benchmarks:
-            tr.write("{:<{}} ".format(benchmark.name, widths['name']))
+            tr.write("{0:<{1}} ".format(benchmark.name, widths['name']))
             for prop in ('min', 'max', 'avg', 'mean', 'stddev'):
                 value = getattr(benchmark, prop)
                 tr.write(
-                    " {:>{}.3f}".format(value * adjustment, widths[prop] + 3),
+                    " {0:>{1}.3f}".format(value * adjustment, widths[prop] + 3),
                     green=value == best[prop],
                     red=value == worst[prop],
                 )
@@ -174,4 +179,3 @@ def pytest_runtest_setup(item):
 def pytest_configure(config):
     config.addinivalue_line("markers", "benchmark: mark a test with custom benchmark settings.")
     config.pluginmanager.register(BenchmarkSession(config), 'pytest-benchmark')
-
